# Generated by Django 6.0.1 on 2026-01-28 16:10

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CommandExecution',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('command_name', models.CharField(help_text='Name of the management command', max_length=255)),
                ('executed_at', models.DateTimeField(auto_now_add=True, help_text='Timestamp when command was executed')),
                ('success', models.BooleanField(default=True, help_text='Whether the command completed successfully')),
                ('parameters', models.JSONField(blank=True, help_text='Command parameters as JSON', null=True)),
                ('output', models.TextField(blank=True, default='', help_text='Command stdout output')),
                ('error_message', models.TextField(blank=True, default='', help_text='Error message if command failed')),
                ('duration', models.FloatField(blank=True, help_text='How long the command took to run (in seconds)', null=True)),
                ('run_once', models.BooleanField(default=False, help_text='Whether this command should only run once')),
            ],
            options={
                'verbose_name': 'Command Execution',
                'verbose_name_plural': 'Command Executions',
                'ordering': ['-executed_at'],
            },
        ),
    ]
