"""
Django Managed Commands

A Django library for tracking management command executions and generating
standardized command boilerplate with integrated testing.
"""

__version__ = "0.1.0"

default_app_config = "django_managed_commands.apps.DjangoManagedCommandsConfig"
